version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter5_application2/anes2012_analysis.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      anes2012_analysis.do                            *;
*       Date:           August 23, 2022                                 *;
*       Author:         MG                                          	*;
*       Purpose:      	Replicate main results for second substantive 	*;
*						application in Chapter 5 looking at ideology, 	*;
*						race, and support for Barack Obama				*;
* 	    Input File:     anes2012_small.dta       		                *;
*       Output File:    none			                                *;
*       Data Output:    none                                            *;             
*       Previous file:  					     						*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter5_application2\anes2012_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*       Drop respondents who are not white or black						*;
*     ****************************************************************  *;

keep if white==1 | black==1;

*     ****************************************************************  *;
*		Generate variable for ideological distance						*;
*     ****************************************************************  *;

gen ideological_distance=abs(left_right-left_right_obama);

*     ****************************************************************  *;
*		Generate interaction term for race and ideological distance		*;
*     ****************************************************************  *;

gen ideological_distance_black=ideological_distance*black;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Some summary statistics											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

sum thermometer_obama ideological_distance black;

* dependent variable among Whites;

sum thermometer_obama if black==0;

* dependent variable among Blacks;

sum thermometer_obama if black==1;

* dependent variable among Whites who are congruent with Obama;

sum thermometer_obama if black==0 & ideological_distance==0;

* ideological incongruence among Whites;

sum ideological_distance if black==0;

* ideological incongruence among Blacks;

sum ideological_distance if black==1;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 5.3 in Chapter 5					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Standard interaction model										*;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black;

*     ****************************************************************  *;
*		Alternative interaction model									*;
*     ****************************************************************  *;

gen ideological_distance_white=ideological_distance*(1-black);

regress thermometer_obama black ideological_distance_white  ideological_distance_black;

*     ****************************************************************  *;
*		Split Sample													*;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance if black==0;

regress thermometer_obama ideological_distance if black==1;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Some effects based on the standard interaction model			*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black;

*     ****************************************************************  *;
*		Variance-covariance matrix of the estimated coefficients		*;
*     ****************************************************************  *;

estat vce;

*     ****************************************************************  *;
*		Obtain degrees of freedom										*;
*     ****************************************************************  *;

scalar df=e(df_r);

display df;

*     ****************************************************************  *;
*		Obtain critical t-value for this degrees of freedom 			*;
*		assuming an alpha level of 0.05					  				*;
*     ****************************************************************  *;

di invttail(df,0.025);

*     ****************************************************************  *;
*		Effect of ideological incongruence among Whites					*;
*     ****************************************************************  *;

lincom _b[ideological_distance];

scalar ideology_whites = r(estimate);
di ideology_whites;

*     ****************************************************************  *;
*		Effect of ideological incongruence among Blacks					*;
*     ****************************************************************  *;

lincom _b[ideological_distance]+_b[ideological_distance_black];

scalar ideology_blacks = r(estimate);
di ideology_blacks;

*     ****************************************************************  *;
*		Interaction effect 												*;
*     ****************************************************************  *;

lincom _b[ideological_distance_black];

*     ****************************************************************  *;
*		Substantive size of interaction effect 							*;
*     ****************************************************************  *;

di ideology_whites/ideology_blacks;

*     ****************************************************************  *;
*		Effect of being Black at different values of ideological		*;
*		incongruence. This provides one column of the information in 	*;
*		Table 5.4. It also provides the point estimates and confidence	*;
*		intervals for Figure 5.4										*;
*     ****************************************************************  *;

lincom _b[black]+_b[ideological_distance_black]*0;

lincom _b[black]+_b[ideological_distance_black]*1;

lincom _b[black]+_b[ideological_distance_black]*2;

lincom _b[black]+_b[ideological_distance_black]*3;

lincom _b[black]+_b[ideological_distance_black]*4;

lincom _b[black]+_b[ideological_distance_black]*5;

lincom _b[black]+_b[ideological_distance_black]*6;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.3 in Stata. Note that the 		*;
*		figures in the book were created using pgfplots, not Stata		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black;

*     ****************************************************************  *;
*		Create a 3 x 2 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot = J(3, 2, .);
matrix coln plot = estimate se;

*     ****************************************************************  *;
*		Obtain the point estimates and standard errors for the effects	*;
*		shown in Figure 5.1 and place them in the matrix				*;
*     ****************************************************************  *;

lincom _b[ideological_distance_black];
matrix plot[1,1]=r(estimate);
matrix plot[1,2]=r(se);

lincom _b[ideological_distance];
matrix plot[2,1]=r(estimate);
matrix plot[2,2]=r(se);

lincom _b[ideological_distance]+_b[ideological_distance_black];
matrix plot[3,1]=r(estimate);
matrix plot[3,2]=r(se);

*     ****************************************************************  *;
*		Produce the plot using coefplot									*;
*     ****************************************************************  *;

coefplot (matrix(plot[.,1]), se(plot[.,2]) offset(0) lwidth(thick) 
		m(smcircle) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))), 
		legend(off) xtitle("Effect Size", size(2.5)) levels(95) 
		xlab(-15 -10 -5 0 5 10, tlcolor(black) labcolor(black) labsize(2.5) format(%9.0f) ) 		
		coeflabels(r1="Interaction Effect for Ideological Incongruence and Race" r2="Effect of Ideological Incongruence among Whites" 
		r3="Effect of Ideological Incongruence among Blacks", tlcolor(black) labcolor(black) labsize(2.5)) 
		yscale(noline) xscale(noline) mlabel format(%9.2f) mlabposition(12) mlabgap(*2) mlabsize(2.5)  
		xline(0, lcolor(gray)) scheme(burd);
		
*     ****************************************************************  *;
*		Obtain remaining information to complete Table 5.4. Note that	*;
*		we only want data for those respondents in our estimation 		*;
*		sample. We can also use this data to produce histograms in 		*;
*		Figures 5.4, 5.5, 5.6b											*;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black;

tab black if e(sample)==1;

tab black if ideological_distance==0 & e(sample)==1;

tab black if ideological_distance==1 & e(sample)==1;

tab black if ideological_distance==2 & e(sample)==1;

tab black if ideological_distance==3 & e(sample)==1;

tab black if ideological_distance==4 & e(sample)==1;

tab black if ideological_distance==5 & e(sample)==1;

tab black if ideological_distance==6 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==0 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==1 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==2 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==3 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==4 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==5 & e(sample)==1;

sum thermometer_obama if black==0 & ideological_distance==6 & e(sample)==1;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.4 in Stata. Note that the		*;
*		figures in the book were created using pgfplots, not Stata		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black;

*     ****************************************************************  *;
*		Create a 7 x 2 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot2 = J(7, 2, .);
matrix coln plot2 = estimate se;

*     ****************************************************************  *;
*		Obtain the point estimates and standard errors for the effects	*;
*		shown in Figure 5.4 and place them in the matrix				*;
*     ****************************************************************  *;

lincom _b[black]+_b[ideological_distance_black]*0;
matrix plot2[1,1]=r(estimate);
matrix plot2[1,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*1;
matrix plot2[2,1]=r(estimate);
matrix plot2[2,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*2;
matrix plot2[3,1]=r(estimate);
matrix plot2[3,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*3;
matrix plot2[4,1]=r(estimate);
matrix plot2[4,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*4;
matrix plot2[5,1]=r(estimate);
matrix plot2[5,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*5;
matrix plot2[6,1]=r(estimate);
matrix plot2[6,2]=r(se);

lincom _b[black]+_b[ideological_distance_black]*6;
matrix plot2[7,1]=r(estimate);
matrix plot2[7,2]=r(se);

*     ****************************************************************  *;
*		Produce the plot using coefplot									*;
*     ****************************************************************  *;

coefplot (matrix(plot2[.,1]), se(plot2[.,2]) offset(0) lwidth(thick) m(smcircle) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))), legend(off) ytitle("Effect of being Black instead of White", size(2.5)) xtitle("Ideological Incongruence between Respondent and Obama", size(2.5)) levels(95) ylab(0 10 20 30 40 50 60 70 80 90, tlcolor(black) labcolor(black) labsize(2.5) format(%9.0f)) coeflabels(r1="0" r2="1" r3="2" r4="3" r5="4" r6="5" r7="6", tlcolor(black) labcolor(black) labsize(2.5)) yscale(noline) xscale(noline) mlabel format(%9.2f) mlabposition(9) mlabgap(*2) mlabsize(2.5)  yline(0, lcolor(gray)) vertical scheme(burd);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.5 in Stata. Note that the		*;
*		figures in the book were created using pgfplots, not Stata		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 6500;

regress thermometer_obama ideological_distance black ideological_distance_black;

*     ****************************************************************  *;
*		Obtain the necessary coefficients, variances, and covariances	*;
*		to calculate effects and confidence intervals					*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=(_n-1)/100;

replace MV=. if _n>620;

gen conbx=b2+b3*MV if _n<620;

gen consx=sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2) if _n<620;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

replace MV=. if MV>6;
replace conbx=. if MV>6;
replace consx=. if MV>6;
replace lowerx=. if MV>6;
replace upperx=. if MV>6;

*     ****************************************************************  *;
*		Produce the plot like Figure 5.5. The plot is not identical		*;
*		to the one in Figure 5.5 because the histogram doesn't 			*;
*		distinguish between Blacks and Whites. It is possible to add	*;
*		histograms by Blacks and Whites but the two histograms each sum	*;
*		to 100 percent when we want them together to sum to 100 		*;
*		percent. There's probably an easy way to get this, but we 		*;
*		didn't use Stata.												*;
*     ****************************************************************  *;

graph twoway hist ideological_distance if e(sample)==1, percent lcolor(white) color(gs13) yaxis(2)
    || line conbx MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    ||,
    xlabel(0 1 2 3 4 5 6, nogrid labsize(2.5))
    ylabel(0 10 20 30 40 50 60 70 80 90, axis(1) nogrid labsize(2.5))
    ylabel(0 5 10 15 20 25, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Effect of being Black instead of White", size(2.5))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(2.5))
    title("", size(3)) subtitle("", size(2.5)) 
    xtitle("Ideological Incongruence between Respondent and Obama", size(2.5)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		At what value of Ideological Incongruence is the confidence		*;
*		interval at its narrowest?										*;
*     ****************************************************************  *;

di covb3b2/varb3;

*     ****************************************************************  *;
*		We can also check this numerically to 2 decimal places.			*;
*     ****************************************************************  *;

gen gap = upperx-lowerx;
sum gap;
scalar min_gap = r(min);
di min_gap;
list MV if gap==min_gap;

*     ****************************************************************  *;
*		Mean of Ideological Incongruence in the estimation sample is	*;
*		NOT the same.													*;
*     ****************************************************************  *;

sum ideological_distance if e(sample)==1;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Some more stuff with the alternative interaction model			*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_obama black ideological_distance_white  ideological_distance_black;

*     ****************************************************************  *;
*		Interaction effect												*;
*     ****************************************************************  *;

lincom _b[ideological_distance_black]-_b[ideological_distance_white];

*     ****************************************************************  *;
*		Effect of being Black for different values of Ideological		*;
*		Incongruence.													*;
*     ****************************************************************  *;

lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*0;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*1;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*2;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*3;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*4;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*5;
lincom _b[black]+(_b[ideological_distance_black]-_b[ideological_distance_white])*6;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Let's add some control variables to get results for Table 5.5	*;
*     ****************************************************************  *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*		Standard interaction model										*;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black democrat republican age female income highschool undergrad grad;

*     ****************************************************************  *;
*		Alternative interaction model									*;
*     ****************************************************************  *;

regress thermometer_obama black ideological_distance_white  ideological_distance_black democrat republican age female income highschool undergrad grad;

*     ****************************************************************  *;
*		Add controls - split sample										*;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance democrat republican age female income highschool undergrad grad if black==0;

regress thermometer_obama ideological_distance democrat republican age female income highschool undergrad grad if black==1;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.7a in Stata. Note that the 		*;
*		figures in the book were created using pgfplots, not Stata		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_obama ideological_distance black ideological_distance_black democrat republican age female income highschool undergrad grad;

*     ****************************************************************  *;
*		Create a 3 x 2 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot3 = J(3, 2, .);
matrix coln plot3 = estimate se;

*     ****************************************************************  *;
*		Obtain the point estimates and standard errors for the effects	*;
*		shown in Figure 5.7a and place them in the matrix				*;
*     ****************************************************************  *;

lincom _b[ideological_distance_black];
matrix plot3[1,1]=r(estimate);
matrix plot3[1,2]=r(se);

lincom _b[ideological_distance];
matrix plot3[2,1]=r(estimate);
matrix plot3[2,2]=r(se);

lincom _b[ideological_distance]+_b[ideological_distance_black];
matrix plot3[3,1]=r(estimate);
matrix plot3[3,2]=r(se);

*     ****************************************************************  *;
*		Produce the plot using coefplot									*;
*     ****************************************************************  *;

coefplot (matrix(plot3[.,1]), se(plot3[.,2]) offset(0) lwidth(thick) 
		m(smcircle) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))), 
		legend(off) xtitle("Effect Size", size(2.5)) levels(95) 
		xlab(-12 -10 -8 -6 -4 -2 0 2 4 6 8 10, tlcolor(black) labcolor(black) labsize(2.5) format(%9.0f) ) 		
		coeflabels(r1="Interaction Effect for Ideological Incongruence and Race" r2="Effect of Ideological Incongruence among Whites" 
		r3="Effect of Ideological Incongruence among Blacks", tlcolor(black) labcolor(black) labsize(2.5)) 
		yscale(noline) xscale(noline) mlabel format(%9.2f) mlabposition(12) mlabgap(*2) mlabsize(2.5)  
		xline(0, lcolor(gray)) scheme(burd);
		
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.7b in Stata. Note that the 		*;
*		figures in the book were created using pgfplots, not Stata		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop MV conbx consx lowerx upperx gap;

regress thermometer_obama ideological_distance black ideological_distance_black democrat republican age female income highschool undergrad grad;

*     ****************************************************************  *;
*		Obtain the necessary coefficients, variances, and covariances	*;
*		to calculate effects and confidence intervals					*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=(_n-1)/100;

replace MV=. if _n>620;

gen conbx=b2+b3*MV if _n<620;

gen consx=sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2) if _n<620;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

replace MV=. if MV>6;
replace conbx=. if MV>6;
replace consx=. if MV>6;
replace lowerx=. if MV>6;
replace upperx=. if MV>6;

*     ****************************************************************  *;
*		Produce the plot like Figure 5.7b. The plot is not identical	*;
*		to the one in Figure 5.7b because the histogram doesn't 		*;
*		distinguish between Blacks and Whites.							*;
*     ****************************************************************  *;

graph twoway hist ideological_distance if e(sample)==1, percent lcolor(white) color(gs13) yaxis(2)
    || line conbx MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    ||,
    xlabel(0 1 2 3 4 5 6, nogrid labsize(2.5))
    ylabel(0 10 20 30 40 50 60 70, axis(1) nogrid labsize(2.5))
    ylabel(0 5 10 15 20 25, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Effect of being Black instead of White", size(2.5))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(2.5))
    title("", size(3)) subtitle("", size(2.5)) 
    xtitle("Ideological Incongruence between Respondent and Obama", size(2.5)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
    
*     ****************************************************************  *;
*       Replication complete											*;
*     ****************************************************************  *;

log close;

clear;

