version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter5_application3/analysis.log", replace
#delimit ;


*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      analysis.do                                     *;
*       Date:           January 19, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for third substantive 	*;
*						application in Chapter 5 looking at demand, 	*;
*						supply, and women's representation				*;
* 	    Input File:     final.dta		                                *;
*       Output File:    analysis.log                                    *;
*       Data Output:    final.dta                                       *;             
*       Previous file:                                  				*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*        Load skeleton dataset                                          *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter5_application3\final.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

*     ****************************************************************  *;
*           Some summary statistics										*;
*     ****************************************************************  *;

sum;

sum womens_representation if year>1989;

sum women_leaders;
scalar min_leader = r(min);
di min_leader;
list women_leaders country year if women_leaders==min_leader;
scalar max_leader = r(max);
di max_leader;
list women_leaders country year if women_leaders==max_leader;

sum labor;
scalar min_labor = r(min);
di min_labor;
list labor country year if labor==min_labor;
scalar max_labor = r(max);
di max_labor;
list labor country year if labor==max_labor;
 
*     ****************************************************************  *;
*		Generate interaction term										*;
*     ****************************************************************  *;

gen leaders_labor = women_leaders*labor;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 5.6 in Chapter 5					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Standard interaction model - uncentered							*;
*     ****************************************************************  *;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

vif;

*     ****************************************************************  *;
*		Standard interaction model - centered							*;
*     ****************************************************************  *;

summarize women_leaders, meanonly;
gen centered_women_leaders = women_leaders - r(mean);

summarize labor, meanonly;
gen centered_labor = labor- r(mean);

gen centered_demand_supply= centered_women_leaders*centered_labor;

regress womens_representation centered_women_leaders centered_labor centered_demand_supply effectivequota polity;

vif;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Some effects based on the uncentered standard interaction model	*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

estat vce;

sum labor;
scalar supply_min=r(min);
scalar supply_max=r(max);
scalar supply_mean=r(mean);
di supply_min;
di supply_max;
di supply_mean;

sum women_leaders;
scalar demand_min=r(min);
scalar demand_max=r(max);
scalar demand_mean=r(mean);
di demand_min;
di demand_max;
di demand_mean;

*     ****************************************************************  *;
*		Effect of demand when supply is at its minimum observed value	*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*supply_min;

*     ****************************************************************  *;
*		Effect of demand when supply is at its maximum observed value	*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*supply_max;

*     ****************************************************************  *;
*		Effect of supply when demand is at its minimum observed value	*;
*     ****************************************************************  *;

lincom _b[labor]+_b[leaders_labor]*demand_min;

*     ****************************************************************  *;
*		Effect of supply when demand is at its maximum observed value	*;
*     ****************************************************************  *;

lincom _b[labor]+_b[leaders_labor]*demand_max;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.8a in Stata showing the marginal	*;
*		effect of demand across the observed range of values for supply.*;
*		Note that the figures in the book were created using pgfplots, 	*;
*		not Stata														*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 100000;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

sum labor;
sum women_leaders;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=((_n-1)/100);

replace MV=. if _n>11200;

gen conbx=b1+b3*MV if _n<11300;

gen consx=sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) if _n<11300;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Limit to range of observed data.								*;
*     ****************************************************************  *;

replace MV=. if MV<8.62;
replace MV=. if MV>111.02;

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 5.8a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist labor, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
		ytitle("Marginal Effect of Demand", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
		xtitle("Supply (Ratio of Female to Male Labor Force Participation)", size(2.5))  
		ytitle("Percentage of Observations", axis(2) size(2.5))
     	xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(-1 111) clpatter(shortdash) color(black) 
	||, xlabel(0 10 20 30 40 50 60 70 80 90 100 110, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    ylabel(0 2 4 6 8 10, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	        
	    
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		When is the effect of demand negative and statistically 		*;
*		insignificant?													*;
*     ****************************************************************  *;

di -_b[women_leaders]/_b[leaders_labor];

sum labor;
scalar total=r(N);
di total;

sum labor if labor<36.94;
scalar subtotal1=r(N);
di subtotal1;
di (subtotal1/total)*100;

*     ****************************************************************  *;
*		When is the effect of demand positive and statistically 		*;
*		insignificant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8a. We use the values in the data editor. The 	*;
*		range is between 36.94 and 50.88.								*;
*     ****************************************************************  *;

sum labor if labor>36.94 & labor<50.88;
scalar subtotal2=r(N);
di subtotal2;
di (subtotal2/total)*100;

*     ****************************************************************  *;
*		When is the effect of demand positive and statistically 		*;
*		significant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8a. We use the values in the data editor. It 	*;
*		occurs when supply is larger than 50.88							*;
*     ****************************************************************  *;

sum labor if labor>50.88;
scalar subtotal3=r(N);
di subtotal3;
di (subtotal3/total)*100;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		What about substantive significance of effect of demand?		*;
*     ****************************************************************  *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*		20 unit increase in demand when supply is at mean and max 		*;
*		values.															*;
*     ****************************************************************  *;

sum womens_representation if year==2018;
scalar rep2018=r(mean);

sum women_leaders;
scalar demand_sd=r(sd);
di demand_sd;

lincom (_b[women_leaders]+_b[leaders_labor]*supply_mean)*20;
scalar effect_mean = r(estimate);
di (effect_mean/rep2018)*100;

lincom (_b[women_leaders]+_b[leaders_labor]*supply_max)*20;
scalar effect_max = r(estimate);
di (effect_max/rep2018)*100;

*	Modifying effect of supply;

di (effect_max/effect_mean)*100;

di ((effect_max-effect_mean)/rep2018)*100;

*     ****************************************************************  *;
*		Effect of one unit increase in demand when supply is at mean	*;
*		and max values.													*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*supply_mean;

lincom _b[women_leaders]+_b[leaders_labor]*supply_max;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.8b in Stata showing the marginal	*;
*		effect of supply across the observed range of values for demand.*;
*		Note that the figures in the book were created using pgfplots, 	*;
*		not Stata														*;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop MV conbx consx lowerx upperx;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

sum labor;
sum women_leaders;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=((_n-1)/100);

gen conbx=b2+b3*MV if _n<9400;

gen consx=sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2) if _n<9400;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Limit to range of observed data.								*;
*     ****************************************************************  *;

replace MV=. if MV<7.98;
replace MV=. if MV>91.83;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 5.8b because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist women_leaders, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
		ytitle("Marginal Effect of Supply", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
		xtitle("Demand", size(2.5)) ytitle("Percentage of Observations", axis(2) size(2.5))
     	xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(-1 100) clpatter(shortdash) color(black) 
	||, xlabel(0 10 20 30 40 50 60 70 80 90 100, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.2 -0.1 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 , tlcolor(black) labcolor(black) axis(1) labsize(2))  
	    ylabel(0 2 4 6 8 10 12 14, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd); 
	    
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		When is the effect of supply negative and statistically 		*;
*		insignificant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8b. We use the values in the data editor. It 	*;
*		occurs when demand is less than 16.36.							*;
*     ****************************************************************  *;

sum women_leaders;
scalar total2=r(N);
di total2;

sum women_leaders if women_leaders<16.36;
scalar subtotal2=r(N);
di subtotal2;
di (subtotal2/total2)*100;

*     ****************************************************************  *;
*		When is the effect of supply positive and statistically 		*;
*		insignificant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8b. We use the values in the data editor. The 	*;
*		range is between 16.36 and 26.52.								*;
*     ****************************************************************  *;

sum women_leaders if women_leaders>16.35 & women_leaders<26.52;
scalar subtotal3=r(N);
di subtotal3;
di (subtotal3/total2)*100;

*     ****************************************************************  *;
*		When is the effect of supply positive and statistically 		*;
*		significant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8b. It occurs when demand is larger than 26.52	*;
*     ****************************************************************  *;

sum women_leaders if women_leaders>26.52;
scalar subtotal4=r(N);
di subtotal4;
di (subtotal4/total2)*100;

*     ****************************************************************  *;
*		When is the effect of supply positive and statistically 		*;
*		insignificant?	You can use the method shown in Online Appendix	*;
*		D to calculate the relevant cutpoint or you can look at the 	*;
*		values in the data editor that we calculated when producing the	*;
*		plot in Figure 5.8b. We use the values in the data editor. The 	*;
*		range is between 16.36 and 26.52.								*;
*     ****************************************************************  *;

sum women_leaders if women_leaders>16.35 & women_leaders<26.52;
scalar subtotal3=r(N);
di subtotal3;
di (subtotal3/total2)*100;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		What about substantive significance of effect of supply?		*;
*     ****************************************************************  *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*		20 unit increase in supply when demand is at mean and max 		*;
*		values.															*;
*     ****************************************************************  *;

sum womens_representation if year==2018;
scalar rep2018=r(mean);
di rep2018;

sum labor;
scalar labor_sd=r(sd);
di labor_sd;

di demand_mean;
di demand_max;

lincom (_b[labor]+_b[leaders_labor]*demand_mean)*20;
scalar effect_mean2 = r(estimate);
di (effect_mean2/rep2018)*100;

lincom (_b[labor]+_b[leaders_labor]*demand_max)*20;
scalar effect_max2 = r(estimate);
di (effect_max2/rep2018)*100;

*	Modifying effect of demand;

di (effect_max2/effect_mean2)*100;

di ((effect_max2-effect_mean2)/rep2018)*100;

*     ****************************************************************  *;
*		Effect of one unit increase in supply when demand is at mean	*;
*		and max values.													*;
*     ****************************************************************  *;

lincom _b[labor]+_b[leaders_labor]*demand_mean;

lincom _b[labor]+_b[leaders_labor]*demand_max;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Figure 5.9. None of the figures in the book were created in 	*;
*		Stata. To see how this figure was created, see the document		*;
*		showing how all of the figures in the book were created.		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Predicted values - these give the four corners of the surface	*;
*		in Figure 5.9													*;
*     ****************************************************************  *;

lincom _b[_cons]+_b[women_leaders]*0+_b[labor]*0+_b[leaders_labor]*0+_b[effectivequota]*1 + _b[polity]*6;

lincom _b[_cons]+_b[women_leaders]*100+_b[labor]*111+_b[leaders_labor]*100*111+_b[effectivequota]*1 + _b[polity]*6;

lincom _b[_cons]+_b[women_leaders]*100+_b[labor]*0+_b[leaders_labor]*100*0+_b[effectivequota]*1 + _b[polity]*6;

lincom _b[_cons]+_b[women_leaders]*0+_b[labor]*111+_b[leaders_labor]*0*111+_b[effectivequota]*1 + _b[polity]*6;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Some effects based on the centered standard interaction model	*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress womens_representation centered_women_leaders centered_labor centered_demand_supply effectivequota polity;

vif;

di demand_mean;
di supply_mean;

*     ****************************************************************  *;
*		Effect of demand when supply is 0								*;
*     ****************************************************************  *;

lincom _b[centered_women_leaders]-_b[centered_demand_supply]*supply_mean;

*     ****************************************************************  *;
*		Effect of supply when demand is 0								*;
*     ****************************************************************  *;

lincom _b[centered_labor]-_b[centered_demand_supply]*demand_mean;

*     ****************************************************************  *;
*		What is constant term in uncentered model based on results from	*;
*		centered model?													*;
*     ****************************************************************  *;

lincom _b[_cons]-_b[centered_women_leaders]*demand_mean-_b[centered_labor]*supply_mean+_b[centered_demand_supply]*demand_mean*supply_mean;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Replication Complete											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

log close;

clear;

*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;        
