version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter6_application2/analysis_regime.log", replace
#delimit ;


*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      analysis_regime.do                              *;
*       Date:           January 23, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for second substantive 	*;
*						application in Chapter 6 looking at demand, 	*;
*						supply, regime type and women's representation	*;
* 	    Input File:     final.dta	                                	*;
*       Output File:    analysis_regime.log                             *;
*       Data Output:    final.dta                                       *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

*     ****************************************************************  *;
*           Some summary statistics										*;
*     ****************************************************************  *;

sum;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

tab polity2 if year>1989;

*     ****************************************************************  *;
*		Create interaction terms										*;
*     ****************************************************************  *;

gen leaders_labor = women_leaders*labor;
gen leaders_polity2=women_leaders*polity2;
gen labor_polity2=labor*polity2;
gen leaders_labor_polity2=women_leaders*labor*polity2;
gen effectivequota_polity2=effectivequota*polity2;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 6.3 in Chapter 6					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress womens_representation women_leaders labor polity2 leaders_labor leaders_polity2 labor_polity2 leaders_labor_polity2 effectivequota;

parmest, list(parm estimate stderr dof t p min95 max95);

estat vce;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		The 3-D plot in Figure 6.17a was not created in Stata. The 		*;
*		figures in the book were created using pgfplots. 				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 6.17b in Stata showing how the 	*;
*		modifying effect of supply on the marginal effect of demand 	*;
*		varies across the observed range of values for democracy. Note 	*;
*		that the figures in the book were created using pgfplots, not 	*;
*		Stata.															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get modifying effect when democracy is at its min and max 		*;
*		values.															*;
*     ****************************************************************  *;

lincom _b[leaders_labor]+_b[leaders_labor_polity2]*0;
lincom _b[leaders_labor]+_b[leaders_labor_polity2]*20;

regress womens_representation women_leaders labor polity2 leaders_labor leaders_polity2 labor_polity2 leaders_labor_polity2 effectivequota;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar b7=b[1,7];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar varb6=V[6,6];
scalar varb7=V[7,7];

scalar covb1b4=V[1,4];
scalar covb1b5=V[1,5];
scalar covb4b5=V[4,5];
scalar covb1b7=V[1,7];
scalar covb4b7=V[4,7];
scalar covb5b7=V[5,7];

scalar list b1 b2 b3 b4 b5 b6 b7 varb1 varb2 varb3 varb4 varb5 varb6 varb7 covb1b4 covb1b5 covb4b5 covb1b7 covb4b7 covb5b7;

estat vce;

generate MV=(_n-1)/10;

replace MV=. if _n>201;

gen conbx=b4+b7*MV if _n<202;

gen consx=sqrt(varb4+varb7*(MV^2)+2*MV*covb4b7) if _n<202;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 6.17b because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist polity2 if year>1989,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx MV, clpattern(longdash)  color(ebblue)
		|| line lowerx MV, clpattern(longdash)  color(ebblue)
		|| line conbx MV, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of Supply-Demand Interaction" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Level of Democracy" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(0 20) clpattern(shortdash) color(black)
		|| , xlabel(0 2 4 6 8 10 12 14 16 18 20, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-0.02 -0.01 0 0.01 0.02, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 4 8 12 16 20, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;				

sum polity2 if year>1989;
scalar total=r(N);
di total;

sum polity2 if polity2<1.6 & year>1989;
scalar subtotal1 = r(N);
di subtotal1;
di (subtotal1/total)*100;

sum polity2 if polity2>1.6 & polity2<9 & year>1989;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

sum polity2 if polity2>9 & year>1989;
scalar subtotal3 = r(N);
di subtotal3;
di (subtotal3/total)*100;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 6.17c in Stata showing how the 	*;
*		modifying effect of democracy on the marginal effect of demand 	*;
*		varies across the observed range of values for supply. Note 	*;
*		that the figures in the book were created using pgfplots, not 	*;
*		Stata.															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get modifying effect when supply is at its min and max values.	*;
*     ****************************************************************  *;

lincom _b[leaders_polity2]+_b[leaders_labor_polity2]*0;
lincom _b[leaders_polity2]+_b[leaders_labor_polity2]*111;

drop MV conbx consx lowerx upperx;

generate MV=(_n-1)/10;

replace MV=. if _n>1130;

gen conbx=b5+b7*MV if _n<1130;

gen consx=sqrt(varb5+varb7*(MV^2)+2*MV*covb5b7) if _n<1130;

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Limit to range of observed data.								*;
*     ****************************************************************  *;

replace MV=. if MV<8.6;
replace MV=. if MV>111.1;

*ssc install scheme-burd, replace;

graph twoway hist labor,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx MV, clpattern(longdash)  color(ebblue)
		|| line lowerx MV, clpattern(longdash)  color(ebblue)
		|| line conbx MV, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of Demand-Democracy Interaction" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Supply" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(0 111) clpattern(shortdash) color(black)
		|| , xlabel(0 10 20 30 40 50 60 70 80 90 100 110, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-0.1 -0.08 -0.06 -0.04 -0.02 0 0.02 0.04 0.06 0.08, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 2 4 6 8, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
		
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

sum labor;
scalar total=r(N);
di total;

sum labor if labor<9.5;
scalar subtotal1 = r(N);
di subtotal1;
di (subtotal1/total)*100;

sum labor if labor>9.49 & labor<66.1;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

sum labor if labor>66 & labor<92.3;
scalar subtotal3 = r(N);
di subtotal3;
di (subtotal3/total)*100;

sum labor if labor>92.2;
scalar subtotal4 = r(N);
di subtotal4;
di (subtotal4/total)*100;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 6.18 in Stata showing how the 		*;
*		marginal effect of demand varies across the observed range of 	*;
*		values for supply when democracy is 0 and when democracy is 20.	*;
*		Note that the figures in the book were created using pgfplots,  *;
*		not Stata.														*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get marginal effect of demand when supply and democracy are 	*;
*		0.																*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*0 + _b[leaders_polity2]*0+_b[leaders_labor_polity2]*0*0;

*     ****************************************************************  *;
*		Get marginal effect of demand when supply is at its max and 	*;
*		democracy is 0													*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*111 + _b[leaders_polity2]*0+_b[leaders_labor_polity2]*111*0;

*     ****************************************************************  *;
*		Get marginal effect of demand when supply is 0 and democracy	*;
*		is at its max of 20												*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*0 + _b[leaders_polity2]*20+_b[leaders_labor_polity2]*0*20;

*     ****************************************************************  *;
*		Get marginal effect of demand when supply is at its max and		*;
*		democracy is at its max 										*;
*     ****************************************************************  *;

lincom _b[women_leaders]+_b[leaders_labor]*111 + _b[leaders_polity2]*20+_b[leaders_labor_polity2]*111*20;

drop conbx consx lowerx upperx;

*     ****************************************************************  *;
*		Figure 6.18a - Democracy is 0									*;
*     ****************************************************************  *;
 
gen conbx=b1+b4*MV+b5*0+b7*MV*0;

gen consx=sqrt(varb1 + (MV^2)*varb4 + (0^2)*varb5 + (MV^2)*(0^2)*varb7
						+ 2*MV*covb1b4 + 2*0*covb1b5 + 2*MV*0*covb1b7 + 2*MV*0*covb4b5
						+ 2*(MV^2)*0*covb4b7 + 2*MV*(0^2)*covb5b7);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*ssc install scheme-burd, replace;

graph twoway hist labor if polity2==0,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx MV if MV>8, clpattern(longdash)  color(ebblue)
		|| line lowerx MV if MV>8, clpattern(longdash)  color(ebblue)
		|| line conbx MV if MV>8, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of Demand | Democracy = 0" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Supply" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(0 110) clpattern(shortdash) color(black)
		|| , xlabel(0 10 20 30 40 50 60 70 80 90 100 110, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8 1.0 1.2, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 2 4 6 8 10 12 14 16 18 20 22 24 26, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
		
* Modifying effect of supply on marginal effect of demand when democracy is 0;

lincom _b[leaders_labor]+_b[leaders_labor_polity2]*0;		
			
*     ****************************************************************  *;
*		Figure 6.18ab - Democracy is 20									*;
*     ****************************************************************  *;				

gen conbx2=b1+b4*MV+b5*20 +b7*MV*20;

gen consx2=sqrt(varb1 + (MV^2)*varb4 + (20^2)*varb5 + (MV^2)*(20^2)*varb7
						+ 2*MV*covb1b4 + 2*20*covb1b5 + 2*MV*20*covb1b7 + 2*MV*20*covb4b5
						+ 2*(MV^2)*20*covb4b7 + 2*MV*(20^2)*covb5b7);

gen lowerx2=conbx2-(t*consx2);

gen upperx2=conbx2+(t*consx2);

graph twoway hist labor if polity2==20,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx2 MV if MV>8, clpattern(longdash)  color(ebblue)
		|| line lowerx2 MV if MV>8, clpattern(longdash)  color(ebblue)
		|| line conbx2 MV if MV>8, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of Demand | Democracy = 20" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Supply" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(0 110) clpattern(shortdash) color(black)
		|| , xlabel(0 10 20 30 40 50 60 70 80 90 100 110, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-1.2 -1.0 -0.8 -0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8 1.0 1.2, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 2 4 6 8 10, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);

* Modifying effect of supply on marginal effect of demand when democracy is 0;

lincom _b[leaders_labor]+_b[leaders_labor_polity2]*20;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Percentage of observations where effect of demand is negative 	*;
*		and statistically significant when democracy is 20				*;
*     ****************************************************************  *;
*     ****************************************************************  *;		
		
sum polity2  if polity2==20;
scalar total2=r(N);
di total2;

sum polity2  if labor<42.3 & polity2==20;
scalar subtotal5 = r(N);
di subtotal5;
di (subtotal5/total2)*100;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		What about substantive significance of effect of demand?		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Calculate information to produce Figure 6.19					*;
*     ****************************************************************  *;
*     ****************************************************************  *;


sum labor;
scalar labor_mean=r(mean);
di labor_mean;
scalar labor_max=r(max);
di labor_max;

sum womens_representation if polity2==0;
scalar rep_mindem=r(mean);
di rep_mindem;
sum womens_representation if polity2==20;
scalar rep_maxdem=r(mean);
di rep_maxdem;

*     ****************************************************************  *;
*		20 unit increase in demand when supply is mean and democracy is	*;
*		0																*;
*     ****************************************************************  *;

lincom (_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20;

di (((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20)/rep_mindem)*100;

*     ****************************************************************  *;
*		20 unit increase in demand when supply is mean and democracy is	*;
*		20																*;
*     ****************************************************************  *;

lincom (_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20;

*     ****************************************************************  *;
*		20 unit increase in demand when supply is max and democracy is	*;
*		0																*;
*     ****************************************************************  *;

lincom (_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20;

*     ****************************************************************  *;
*		20 unit increase in demand when supply is max and democracy is	*;
*		20																*;
*     ****************************************************************  *;

lincom (_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20;

di (((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)/rep_maxdem)*100;

*     ****************************************************************  *;
*		Differences														*;
*     ****************************************************************  *;

lincom ((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20);
		
lincom ((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20);
		
di ((((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20))/rep_maxdem)*100;		

lincom ((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20);
		
di ((((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20))/rep_maxdem)*100;

lincom ((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20);
		
	
*     ****************************************************************  *;
*		Difference in differences										*;
*     ****************************************************************  *;		
		
lincom (((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20))
		-(((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20));

lincom (((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_max*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_max+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_max*0)*20))
		-(((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*20+_b[leaders_labor_polity2]*labor_mean*20)*20)
		-((_b[women_leaders]+_b[leaders_labor]*labor_mean+_b[leaders_polity2]*0+_b[leaders_labor_polity2]*labor_mean*0)*20));

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Replication Complete											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

log close;

clear;

*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;        
