version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter7_application1/sentiment.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      sentiment.do                                    *;
*       Date:           January 21, 2022                                *;
*       Author:         MG                                         		*;
*       Purpose:      	Replicate main results for substantive 			*;
*						application in Chapter 7 looking at party		*;
*						ideology and campaign sentiment.				*;
* 	    Input File:     sentiment.dta                                   *;
*       Output File:    sentiment.log                                   *;
*       Data Output:    none                                            *;             
*       Previous file:  sentiment.dta                                   *;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter7_application1\sentiment.dta", clear;

*     ****************************************************************  *;
*		Create quadratic ideology term									*;
*     ****************************************************************  *;

gen left_right2=left_right*left_right;
label var left_right2 "left_right*left_right";

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

*     ****************************************************************  *;
*           Summary statistics											*;
*     ****************************************************************  *;

sum;

sum positive_sentiment;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 7.1 in Chapter 7					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

reg positive_sentiment left_right left_right2;

*     ****************************************************************  *;
*		Calculate value of left-right at which positive sentiment is	*;
*		maximized.														*;
*     ****************************************************************  *;

di -_b[left_right]/(2*_b[left_right2]);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a predicted value plot similar to the one shown in 		*;
*		Figure 7.4a. Note that the figures in the book were created 	*;
*		using pgfplots, not Stata.										*;
*     ****************************************************************  *;
*     ****************************************************************  *;

reg positive_sentiment left_right left_right2;

*     ****************************************************************  *;
*		Obtain the necessary coefficients, variances, and covariances	*;
*		to calculate effects and confidence intervals					*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b0=b[1,3];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb0=V[3,3];

scalar covb1b0=V[1,3];
scalar covb1b2=V[1,2];
scalar covb2b0=V[2,3];

scalar list b0 b1 b2 varb0 varb1 varb2 covb1b0 covb1b2 covb2b0;

estat vce;

generate MV=((_n-1)/10);

replace MV=. if _n>102;

gen predy=b0+b1*MV+b2*MV*MV if _n<102;

gen cons_predy=sqrt(varb0+varb1*(MV^2)+varb2*(MV^4)+2*MV*covb1b0+2*MV*MV*covb2b0+2*MV*MV*MV*covb1b2) if _n<102;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=predy-(t*cons_predy);

gen upperx=predy+(t*cons_predy);

*     ****************************************************************  *;
*		Double check predicted value when left-right is 5.				*;
*     ****************************************************************  *;

lincom _b[_cons]+5*_b[left_right] + 25*_b[left_right2];

margins, at(left_right=5 left_right2=25);

*     ****************************************************************  *;
*		Produce the plot in Figure 7.4a. The histogram will be a little	*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist left_right, percent lcolor(white) color(gs13) yaxis(2)
    || line predy MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || function y = 0, range(0 10) clpatter(shortdash) color(black) 
    ||,
    xlabel(0 1 2 3 4 5 6 7 8 9 10, nogrid labsize(2.5))
    ylabel(-0.5 0  0.5 1 1.5 2 2.5, axis(1) nogrid labsize(2.5))
    ylabel(0 5 10 15 20, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Positive Sentiment", size(3))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(3))
    title("", size(3)) subtitle("", size(3)) xtitle("Left-Right Position", size(3)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Numerically look at the value of left-right where predicted		*;
*		positive sentiment is maximized.								*;
*     ****************************************************************  *;
    
sum predy;
scalar predy_max=r(max);
di predy_max;
list MV if predy==predy_max;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a marginal effect plot for left-right similar to the 	*;
*		one shown in Figure 7.4b. Note that the figures in the book 	*;
*		were created using pgfplots, not Stata.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 1500;

drop lowerx upperx MV;

generate MV=((_n-1)/100);

replace MV=. if _n>1002;

gen conb=b1+2*b2*MV if _n<1002;

gen cons=sqrt(varb1+varb2*4*MV*MV+4*MV*covb1b2) if _n<1002;

gen lowerx=conb-(t*cons);

gen upperx=conb+(t*cons);

*     ****************************************************************  *;
*		Double check marginal effect when left-right is 5.				*;
*     ****************************************************************  *;

lincom _b[left_right] + 2*_b[left_right2]*5;

*     ****************************************************************  *;
*		Produce the plot in Figure 7.4b. The histogram will be a little	*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist left_right, percent lcolor(white) color(gs13) yaxis(2)
    || line conb MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || function y = 0, range(0 10) clpatter(shortdash) color(black) 
    ||,
    xlabel(0 1 2 3 4 5 6 7 8 9 10, nogrid labsize(2.5))
    ylabel(-1.2 -1 -0.8 -0.6 -0.4 -0.2  0  0.2  0.4 0.6 0.8 1, axis(1) nogrid labsize(2.5))
    ylabel(0 5 10 15 20, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Positive Sentiment", size(3))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(3))
    title("", size(3)) subtitle("", size(3)) xtitle("Left-Right Position", size(3)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Percentage of observations that fall into the different regions	*;
*		in the plot using the cutpoints identified in the data editor.	*;
*     ****************************************************************  *;

sum left_right;
scalar total = r(N);
di total;

sum year if left_right<4.69 & left_right~=.;
scalar subtotal = r(N);
di subtotal;
di (subtotal/total)*100;

sum year if left_right>5.68 & left_right~=.;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

 *     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a first difference plot for left-right similar to the 	*;
*		one shown in Figure 7.4c. Note that the figures in the book 	*;
*		were created using pgfplots, not Stata.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;  

drop lowerx upperx conb cons; 

gen conb=b1+b2+2*b2*MV if _n<1002;

gen cons=sqrt(varb1+(1+4*MV+4*MV*MV)*varb2+ (2+4*MV)*covb1b2) if _n<1002;

gen lowerx=conb-(t*cons);

gen upperx=conb+(t*cons);

*     ****************************************************************  *;
*		Double check first difference when left-right is 5.				*;
*     ****************************************************************  *;

lincom _b[left_right] + _b[left_right2]+ 2*_b[left_right2]*5;

*     ****************************************************************  *;
*		Produce the plot in Figure 7.4b. The histogram will be a little	*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist left_right, percent lcolor(white) color(gs13) yaxis(2)
    || line conb MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    ||,
    xlabel(0 1 2 3 4 5 6 7 8 9 10, nogrid labsize(2.5))
    ylabel(-1.2 -1 -0.8 -0.6 -0.4 -0.2  0  0.2  0.4 0.6 0.8 1, axis(1) nogrid labsize(2.5))
    ylabel(0 5 10 15 20, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Positive Sentiment", size(3))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(3))
    title("", size(3)) subtitle("", size(3)) xtitle("Left-Right Position", size(3)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
    
*     ****************************************************************  *;
*		Percentage of observations that fall into the different regions	*;
*		in the plot using the cutpoints identified in the data editor.	*;
*     ****************************************************************  *;

sum left_right;
scalar total = r(N);
di total;

sum year if left_right<4.19 & left_right~=.;
scalar subtotal = r(N);
di subtotal;
di (subtotal/total)*100;

sum year if left_right>5.18 & left_right~=.;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

*     ****************************************************************  *;
*		Substantive significance -- effect of a one unit increase in	*;
*		left-right when left-right is 2. We can look at the information	*;
*		in the data editor, or calculate it manually like below.		*;
*     ****************************************************************  *;

sum left_right;
scalar leftright_sd=r(sd);
di leftright_sd;
di (1/leftright_sd)*100;

di b1+b2+2*b2*2;
di  (b1+b2+2*b2*2)-(t*(sqrt(varb1+(1+4*2+4*2*2)*varb2+ (2+4*2)*covb1b2)));
di  (b1+b2+2*b2*2)+(t*(sqrt(varb1+(1+4*2+4*2*2)*varb2+ (2+4*2)*covb1b2)));

sum positive_sentiment if left_right<=2 & left_right~=.;
scalar sentiment_m=r(mean);
di sentiment_m;
di ((b1+b2+2*b2*2)/sentiment_m)*100;

*     ****************************************************************  *;
*		Substantive significance -- effect of a one unit increase in	*;
*		left-right when left-right is at its mean value.				*;
*     ****************************************************************  *;

sum left_right;
scalar left_right_mean=r(mean);
di left_right_mean;

di b1+b2+2*b2*left_right_mean;

di sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2);

di (b1+b2+2*b2*left_right_mean)-(t*(sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2)));

di (b1+b2+2*b2*left_right_mean)+(t*(sqrt(varb1+(1+4*left_right_mean+4*left_right_mean*left_right_mean)*varb2+ (2+4*left_right_mean)*covb1b2)));

*     ****************************************************************  *;
*       Replication complete                                            *;
*     ****************************************************************  *;

log close;

clear;
