version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_application/pec.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec.do                              			*;
*       Date:           January 23, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for substantive 			*;
*						application in Chapter 8 looking at 			*;
*						determinants of pre-electoral coalition 		*;
*						formation										*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec.log                             			*;
*       Data Output:    pec_BJPS.dta                                    *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*		Get polarization and threshold measures by election.			*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum threshold;
scalar threshold_mean=r(mean);
di threshold_mean;
scalar threshold_sd=r(sd);
di threshold_sd;

sum polarization;
scalar polarization_mean=r(mean);
di polarization_mean;
scalar polarization_sd=r(sd);
di polarization_sd;

sum election;
scalar election_total=r(N);
di election_total;

sum election if threshold>16.74 & threshold~=.;
scalar election_subtotal=r(N);
di election_subtotal;
di (election_subtotal/election_total)*100;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*		Summary statistics												*;
*     ****************************************************************  *;

desc;

summarize pec seatshare incompatibility polarization threshold;

tab pec;

sum polarization if polarization<83.7;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.2 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility, or;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.10a in Stata showing how the 	*;
*		marginal effect of disproportionality varies across the 		*;
*		observed range of values for party system polarization. Note 	*;
*		that the figures in the book were created using pgfplots, not 	*;
*		Stata.															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];
scalar covb4b5=V[4,5];

scalar list b1 b2 b3 b4 b5 varb1 varb2 varb3 varb4 varb5 covb1b3 covb3b2 covb4b5;

estat vce;

generate MV=_n-1;

replace MV=. if _n>101;

gen conbx=b1+b3*MV if _n<102;

gen consx=sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) if _n<102;

*     ****************************************************************  *;
*		Obtain critical z-value for creating confidence intervals		*;
*     ****************************************************************  *;

scalar z=invnormal(0.975);

gen lowerx=conbx-(z*consx);

gen upperx=conbx+(z*consx);

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 8.10a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist polarization, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
	ytitle("Marginal Effect of Disproportionality", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
	xtitle("Party System Polarization", size(2.5)) ytitle("Percentage of Observations", axis(2) size(2.5))
    xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(0 100) clpatter(shortdash) color(black) 
	||, xlabel(0 10 20 30 40 50 60 70 80 90 100, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.02 0 0.02 0.04 0.06 0.08 0.10 0.12, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    ylabel(0 2 4 6 8 10, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);  	
	    	        	    
drop MV conbx consx upperx lowerx;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.10b in Stata showing how the 	*;
*		marginal effect of polarization varies across the observed		*;
*		range of values for disproportionality.  						*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec polarization threshold polarization_threshold seatshare seatshare_2 incompatibility;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=(_n-1)/100;

replace MV=. if _n>3501;

gen conbx=b1+b3*MV if _n<3502;

gen consx=sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) if _n<3502;

scalar z=invnormal(0.975);

gen lowerx=conbx-(z*consx);

gen upperx=conbx+(z*consx);

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 8.10b because the bar widths and locations are 	*;
*		not identical. It also differs because the histogram in Figure	*;
*		8.10b in the book shows information about electoral system 		*;
*		disproportionality per election. Electoral system 				*;
*		disproportionality is a characteristic of the election not a	*;
*		characteristic of the potential coalition dyad.					*;
*     ****************************************************************  *;

graph twoway hist threshold, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
	ytitle("Marginal Effect of Polarization", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
	xtitle("Electoral System Disproportionality", size(2.5)) ytitle("Percentage of Observations", axis(2) size(2.5))
    xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(0 35) clpatter(shortdash) color(black) 
	||,   xlabel(0 5 10 15 20 25 30 35, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.01 0 0.01 0.02 0.03, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    ylabel(0  5 10  15 20 25, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd); 
	        	        	    
drop MV conbx consx upperx lowerx;

*     ****************************************************************  *;
*		Calculate coalition size that maximizes propensity of PEC		*;
*		formation.														*;
*     ****************************************************************  *;

di (-_b[seatshare])/(2*_b[seatshare_2]);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.11a in Stata showing how the 	*;
*		marginal effect of coalition size varies across the observed	*;
*		range of values for coalition size.  							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

matrix b=e(b);
matrix V=e(V);

scalar b0=b[1,7];
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];
scalar covb4b5=V[4,5];

scalar list b0 b1 b2 b3 b4 b5 b6 varb1 varb2 varb3 varb4 varb5 covb1b3 covb3b2 covb4b5;

estat vce;

generate MV=((_n-1)/10);

replace MV=. if _n>1001;

gen conb=b4+b5+2*b5*MV if _n<1002;

gen cons=sqrt(varb4+(1+4*MV+4*MV*MV)*varb5+ (2+4*MV)*covb4b5) if _n<1002;

scalar z=invnormal(0.975);

gen lowerx=conb-(z*cons);

gen upperx=conb+(z*cons);

*     ****************************************************************  *;
*		Double check effect when coalition size is 40					*;
*     ****************************************************************  *;

lincom _b[seatshare] + _b[seatshare_2] + 2*_b[seatshare_2]*40;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 8.11a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist seatshare, percent lcolor(white) color(gs13) yaxis(2)
    || line conb MV, lwidth(medthick) clpattern(solid) color(black)
    || line lowerx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || line upperx MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
    || function y = 0, range(0 100) clpatter(shortdash) color(black)
    ||,
    xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2.5))
    ylabel(-0.15 -0.10 -0.05 0 0.05 0.1, axis(1) nogrid labsize(2.5))
    ylabel(0 1 2 3 4 5 6 7 8 , tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("Effect of Coalition Size", size(3))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(3))
    title("", size(3)) subtitle("", size(3)) xtitle("Expected Coalition Size", size(3)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
    
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;				

sum seatshare;
scalar total=r(N);
di total;

sum seatshare if seatshare<27.3;
scalar subtotal1 = r(N);
di subtotal1;
di (subtotal1/total)*100;

sum seatshare if seatshare>45.9 & seatshare~=.;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

*     ****************************************************************  *;				
*		Identify values to be used for histogram in Figures 8.11a and	*;
*		8.11b															*;
*     ****************************************************************  *;				

sum seatshare if seatshare>-0.01 & seatshare<5;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>4.999 & seatshare<10;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>9.999 & seatshare<15;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>14.999 & seatshare<20;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>19.999 & seatshare<25;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>24.999 & seatshare<30;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>29.999 & seatshare<35;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>34.999 & seatshare<40;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>39.999 & seatshare<45;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>44.999 & seatshare<50;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>49.999 & seatshare<55;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>54.999 & seatshare<60;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>59.999 & seatshare<65;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>64.999 & seatshare<70;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>69.999 & seatshare<75;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>74.999 & seatshare<80;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>79.999 & seatshare<85;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>84.999 & seatshare<90;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>89.999 & seatshare<95;
scalar subtotal=r(N);
di (subtotal/total)*100;
sum seatshare if seatshare>94.999 & seatshare<100.01;
scalar subtotal=r(N);
di (subtotal/total)*100;

drop MV conb cons upperx lowerx;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.11b in Stata showing how the 	*;
*		predicted propensity of PEC formation varies across the 		*;
*		observed range of values for coalition size when 				*;
*		Disproportionality, Polarization, and Ideological 				*;
*		Incompatibility are all at their mean values.  					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

sum incompatibility;
scalar incompatibility_mean=r(mean);
di incompatibility_mean;

generate MV=((_n-1)/10);

replace MV=. if _n>1001;

gen predy=b0+b1*threshold_mean+b2*polarization_mean+b3*threshold_mean*polarization_mean+b4*MV+b5*MV*MV + b6*incompatibility_mean if _n<1002;

*     ****************************************************************  *;
*		Double check predicted value when seatshare is 20.				*;
*     ****************************************************************  *;

lincom _b[_cons]+ _b[threshold]*threshold_mean + _b[polarization]*polarization_mean 
			+ _b[polarization_threshold]*threshold_mean*polarization_mean + _b[seatshare]*20 + _b[seatshare_2]*20*20 
			+ _b[incompatibility]*incompatibility_mean;

*     ****************************************************************  *;
*		Produce the plot in Figure 8.11b. The histogram will be a little*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist seatshare, percent lcolor(white) color(gs13) yaxis(2)
    || line predy MV, lwidth(medthick) clpattern(solid) color(black)
    ||,
    xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2.5))
    ylabel(-5 -4.5 -4 -3.5 -3 -2.5, axis(1) nogrid labsize(2.5))
    ylabel(0 2 4 6 8 10 12, tlcolor(gs13) labcolor(gs13) axis(2) nogrid labsize(2.5))
    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
    ytitle("PEC*", size(3))
    ytitle("Percentage of Observations", color(gs12) axis(2) size(3))
    title("", size(3)) subtitle("", size(3)) xtitle("Expected Coalition Size", size(3)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
    
*     ****************************************************************  *;
*		Numerically look at the value of seatshare where PEC* is		*;
*		maximized.														*;
*     ****************************************************************  *;
    
sum predy;
scalar predy_max=r(max);
di predy_max;
list MV if predy==predy_max;

*     ****************************************************************  *;
*		And precisely ...												*;
*     ****************************************************************  *;

di -b4/(2*b5);

*     ****************************************************************  *;
*		Replication complete											*;
*     ****************************************************************  *;

log close;
exit;
