version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_application/pec3.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec2.do                              			*;
*       Date:           January 28, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for substantive 			*;
*						effects of polarization in the application in 	*;
*						Chapter 8 looking at the determinants of 		*;
*						pre-electoral coalition formation				*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec3.log                             			*;
*       Data Output:    pec_BJPS.dta                                    *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*		Get polarization standard deviation by election.				*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum polarization;
scalar polarization_sd=r(sd);
di polarization_sd;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*		Summary statistics												*;
*     ****************************************************************  *;

desc;

summarize pec seatshare incompatibility polarization threshold;

tab pec;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.2 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility, or;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.15 in Stata. Percentage change	*;
*		in the odds of PEC formation associated with a one standard 	*;
*		deviation increase in Polarization.								*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		One way to get the information necessary to produce this 		*;
*		figure is to use Stata's lincom command. This is what we used.	*;
*     ****************************************************************  *;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim2.dta", replace;	
		
noisily display "start";

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

local a=0 ;
while `a' <= 35.1 { ;
{;

lincom (_b[polarization]+_b[polarization_threshold]*`a')*polarization_sd, or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim2.dta";

gen yline=1;

gen MV = (_n-1)/10;

replace MV=. if _n>351;

*     ****************************************************************  *;
*		Graph odds ratio associated with a one standard deviation 		*;
*		increase in Polarization. The histogram differs slightly from 	*;
*		the one in Figure 8.15 because the bar widths and locations are *;
*		not identical. It also differs because the histogram in Figure	*;
*		8.15 in the book shows information about electoral system 		*;
*		disproportionality per election. Electoral system 				*;
*		disproportionality is a characteristic of the election not a	*;
*		characteristic of the potential coalition dyad.					*;
*     ****************************************************************  *;										

graph twoway hist threshold, percent color(gs13) yaxis(2)
		|| line odds_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 5 10 15 20 25 30 35, nogrid labsize(2))
			ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
			ylabel(0.6 0.8 1 1.2 1.4 1.6 1.8 2, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black) lpattern(dashed))
			ytitle("Odds of Pre-Electoral Coalition Formation", size(2))
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Electoral System Disproportionality", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
					
*     ****************************************************************  *;
*		Get percentage change in odds									*;
*     ****************************************************************  *;
    
gen odds_percent=(odds_hat-1)*100;
gen odds_percent_lo=(odds_lo-1)*100;
gen odds_percent_hi=(odds_hi-1)*100;

*     ****************************************************************  *;
*		Figure 8.15														*;
*     ****************************************************************  *;

graph twoway hist threshold, percent color(gs13) yaxis(2)
		|| line odds_percent MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_percent_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_percent_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 5 10 15 20 25 30 35, nogrid labsize(2))
			ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
			ylabel(-30 0 30 60 90, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			ytitle("Percentage Change in Odds of Pre-Electoral Coalition Formation", size(2))
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Electoral System Disproportionality", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Some specific values											*;
*     ****************************************************************  *;

list MV odds_percent odds_percent_lo odds_percent_hi if _n==143;
sum odds_percent if _n==143;
scalar mean=r(mean);
di mean;

list MV odds_percent odds_percent_lo odds_percent_hi if _n==276;
sum odds_percent if _n==276;
scalar meanplus=r(mean);
di meanplus;

di ((meanplus/mean)-1)*100;

drop _merge odds_percent odds_percent_lo odds_percent_hi odds_hat odds_lo odds_hi MV;

*     ****************************************************************  *;
*		Rather than use Stata's lincom command, we could do this 		*;
*		manually via simulation											*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

preserve;

set seed 10101;

drawnorm SN_b1-SN_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi odds_percent odds_percent_lo odds_percent_hi 
		using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim3.dta", replace;	
		
noisily display "start";

local a=0 ;
while `a' <= 35 { ;
{;

generate x_betahat= (SN_b2 + SN_b3*`a')*polarization_sd;
		
gen odds =exp(x_betahat);	
gen oddspercent=(exp(x_betahat)-1)*100;
		
egen oddshat =mean(odds);
egen oddspercenthat=mean(oddspercent);

tempname odds_hat odds_lo odds_hi odds_percent odds_percent_lo odds_percent_hi;

_pctile odds, p(2.5,97.5) ;
scalar `odds_lo' = r(r1);
scalar `odds_hi' = r(r2);
scalar `odds_hat'=oddshat;

_pctile oddspercent, p(2.5,97.5) ;
scalar `odds_percent_lo' = r(r1);
scalar `odds_percent_hi' = r(r2);
scalar `odds_percent'=oddspercenthat;

post mypost (`odds_hat') (`odds_lo') (`odds_hi') (`odds_percent') (`odds_percent_lo') (`odds_percent_hi');

};

drop x_betahat odds oddshat oddspercent oddspercenthat;
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim3.dta";

gen MV = (_n-1)/10;

replace MV=. if _n>351;
  
graph twoway hist threshold, percent color(gs13) yaxis(2)
		|| line odds_percent MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_percent_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_percent_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 5 10 15 20 25 30 35, nogrid labsize(2))
			ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
			ylabel(-30 0 30 60 90, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			ytitle("Percentage Change in Odds of Pre-Electoral Coalition Formation", size(2))
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Electoral System Disproportionality", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

log close;
exit;
